.. _timeseries:

Timeseries ('stixpy.timeseries')
*********************************

The ``timeseries`` submodule provides classes to load and interact with certain data using
sunpy `~sunpy.timeseries.TimeSeries`.

.. automodapi:: stixpy.timeseries

.. automodapi:: stixpy.timeseries.quicklook
